@@ -4,11 +4,32 @@
 #  for CSV responses (get_measurements) the readr package is a hidden dependency
 # ==============================================================================
 
+default_api = 'https://api.opensensemap.org'
+
 #' Get the default openSenseMap API endpoint
 #' @export
 #' @return A character string with the HTTP URL of the openSenseMap API
-osem_endpoint = function() {
-  'https://api.opensensemap.org'
+osem_endpoint = function() default_api
+
+#' Check if the given openSenseMap API endpoint is available
+#' @param endpoint The API base URL to check, defaulting to \code{\link{osem_endpoint}}
+#' @return \code{TRUE} if the API is available, otherwise \code{stop()} is called.
+osem_ensure_api_available = function(endpoint = osem_endpoint()) {
+  code = FALSE
+  try({
+    code = httr::status_code(httr::GET(endpoint, path='stats'))
+  }, silent = TRUE)
+  
+  if (code == 200)
+    return(TRUE)
+  
+  errtext = paste('The API at', endpoint, 'is currently not available.')
+  if (code != FALSE)
+    errtext = paste0(errtext, ' (HTTP code ', code, ')')
+  if (endpoint == default_api)
+    errtext = c(errtext, 'If the issue persists, please check back at https://status.sensebox.de/778247404 and notify support@sensebox.de')
+  stop(paste(errtext, collapse='\n  '), call. = FALSE)
+  FALSE
 }
 
 get_boxes_ = function (..., endpoint) {
@@ -24,8 +45,9 @@ get_boxes_ = function (..., endpoint) {
   df = dplyr::bind_rows(boxesList)
   df$exposure = df$exposure %>% as.factor()
   df$model    = df$model %>% as.factor()
-  if (!is.null(df$grouptag))
+  if (!is.null(df$grouptag)){
     df$grouptag = df$grouptag %>% as.factor()
+  }
   df
 }
 
@@ -49,7 +71,7 @@ parse_measurement_csv = function (resText) {
   })
 
   osem_as_measurements(result)
-}
+} 
 
 get_measurements_ = function (..., endpoint) {
   osem_get_resource(endpoint, c('boxes', 'data'), ..., type = 'text') %>%
@@ -72,7 +94,7 @@ get_stats_ = function (endpoint, cache) {
 #' @param cache Optional path to a directory were responses will be cached. If not NA, no requests will be made when a request for the given is already cached.
 #' @return Result of a Request to openSenseMap API
 #' @noRd
-osem_get_resource = function (host, path, ..., type = 'parsed', progress = T, cache = NA) {
+osem_get_resource = function (host, path, ..., type = 'parsed', progress = TRUE, cache = NA) {
   query = list(...)
   if (!is.na(cache)) {
     filename = osem_cache_filename(path, query, host) %>% paste(cache, ., sep = '/')
@@ -99,11 +121,12 @@ osem_cache_filename = function (path, query = list(), host = osem_endpoint()) {
 #'
 #' @export
 #' @examples
-#' \donttest{
+#' \dontrun{
 #'   osem_boxes(cache = tempdir())
 #'   osem_clear_cache()
 #'
 #'   cachedir = paste(getwd(), 'osemcache', sep = '/')
+#'   dir.create(file.path(cachedir), showWarnings = FALSE)
 #'   osem_boxes(cache = cachedir)
 #'   osem_clear_cache(cachedir)
 #' }
@@ -115,6 +138,9 @@ osem_clear_cache = function (location = tempdir()) {
 }
 
 osem_request_ = function (host, path, query = list(), type = 'parsed', progress = TRUE) {
+  # stop() if API is not available
+  osem_ensure_api_available(host)
+  
   progress = if (progress && !is_non_interactive()) httr::progress() else NULL
   res = httr::GET(host, progress, path = path, query = query)
 
